==> mfc-api-model-0.1.5-sources.jar: com/valor/mfc/vms/api/model/tag/TagDo.java <==
package com.valor.mfc.vms.api.model.tag;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

import java.util.Objects;

/**
 * Created by Frank.Huang on 2016/7/9.
 */
public class TagDo extends AbstractPrintable {
    private ETagPostion position; //位置
    private ETagType type;        //类型
    private int seq        = 0;   //seq

    private String acl = "";  //访问控制列表
    private String content = "";  //内容

    public ETagPostion getPosition() {
        return position;
    }

    public void setPosition(ETagPostion position) {
        this.position = position;
    }

    public ETagType getType() {
        return type;
    }

    public void setType(ETagType type) {
        this.type = type;
    }

    public int getSeq() {
        return seq;
    }

    public void setSeq(int seq) {
        this.seq = seq;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getAcl() {
        return acl;
    }

    public void setAcl(String acl) {
        this.acl = acl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TagDo tagDo = (TagDo) o;
        return seq == tagDo.seq &&
                position == tagDo.position &&
                type == tagDo.type &&
                Objects.equals(content, tagDo.content);
    }

    @Override
    public int hashCode() {
        return Objects.hash(position, type, seq, content);
    }
}

==> mfc-api-model-0.1.7-sources.jar: com/valor/mfc/vms/api/model/tag/TagDo.java <==
package com.valor.mfc.vms.api.model.tag;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

import java.util.Objects;

/**
 * Created by Frank.Huang on 2016/7/9.
 */
public class TagDo extends AbstractPrintable {
    private ETagPostion position; //位置
    private ETagType type;        //类型
    private int seq        = 0;   //seq

    private String acl = "";  //访问控制列表
    private String content = "";  //内容

    /**
     * 2.3版本新增，数据类型
     */
    private String dataType = "";

    public ETagPostion getPosition() {
        return position;
    }

    public void setPosition(ETagPostion position) {
        this.position = position;
    }

    public ETagType getType() {
        return type;
    }

    public void setType(ETagType type) {
        this.type = type;
    }

    public int getSeq() {
        return seq;
    }

    public void setSeq(int seq) {
        this.seq = seq;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getAcl() {
        return acl;
    }

    public void setAcl(String acl) {
        this.acl = acl;
    }

    public String getDataType() {
        return dataType;
    }

    public void setDataType(String dataType) {
        this.dataType = dataType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TagDo tagDo = (TagDo) o;
        return seq == tagDo.seq &&
                position == tagDo.position &&
                type == tagDo.type &&
                Objects.equals(content, tagDo.content);
    }

    @Override
    public int hashCode() {
        return Objects.hash(position, type, seq, content);
    }
}
